@@ -8,6 +8,8 @@ Note that this file won't be executed on its own by pytest.
 You need to define your own test cases that import the ones defined here.
 Here is an example of how you would do that:
 
+.. code:: python
+
     from orquestra.quantum.api.estimator_contract import ESTIMATOR_CONTRACTS
 
     @pytest.mark.parametrize("contract", ESTIMATOR_CONTRACTS)
@@ -19,9 +21,9 @@ Here is an example of how you would do that:
 import numpy as np
 
 from ..api.estimation import EstimateExpectationValues, EstimationTask
-from ..backends.symbolic_simulator import SymbolicSimulator
 from ..circuits import RX, RY, RZ, Circuit, H
 from ..operators import PauliTerm
+from ..runners.symbolic_simulator import SymbolicSimulator
 
 _backend = SymbolicSimulator(seed=1997)
 
@@ -52,7 +54,7 @@ def _validate_each_task_returns_one_expecation_value(
 ):
     # When
     expectation_values = estimator(
-        backend=_backend,
+        runner=_backend,
         estimation_tasks=_estimation_tasks,
     )
 
@@ -64,7 +66,7 @@ def _validate_order_of_outputs_matches_order_of_inputs(
     estimator: EstimateExpectationValues,
 ):
     expectation_values = estimator(
-        backend=_backend,
+        runner=_backend,
         estimation_tasks=_estimation_tasks,
     )
 
@@ -73,7 +75,7 @@ def _validate_order_of_outputs_matches_order_of_inputs(
             np.allclose(
                 expectation_values[i].values,
                 estimator(
-                    backend=_backend,
+                    runner=_backend,
                     estimation_tasks=[task],
                 )[0].values,
                 rtol=0.1,  # 10% tolerance
@@ -95,7 +97,7 @@ def _validate_expectation_value_includes_coefficients(
     ]
 
     expectation_values = estimator(
-        backend=_backend,
+        runner=_backend,
         estimation_tasks=estimation_tasks,
     )
 
@@ -119,7 +121,7 @@ def _validate_constant_terms_are_included_in_output(
     ]
 
     expectation_values = estimator(
-        backend=_backend,
+        runner=_backend,
         estimation_tasks=estimation_tasks,
     )
 
