@@ -147,6 +147,7 @@ from ._builtin_gates import (
     CPHASE,
     CZ,
     ISWAP,
+    MS,
     PHASE,
     RH,
     RX,
@@ -160,6 +161,8 @@ from ._builtin_gates import (
     ZZ,
     Delay,
     GatePrototype,
+    GPi,
+    GPi2,
     H,
     I,
     S,
@@ -185,6 +188,7 @@ from ._generators import (
     create_layer_of_gates,
 )
 from ._itertools import (
+    combine_bitstrings,
     combine_measurement_counts,
     expand_sample_sizes,
     split_into_batches,
