@@ -35,8 +35,10 @@ if TYPE_CHECKING:
 
 
 def compute_rbf_kernel(x_i: np.ndarray, y_j: np.ndarray, sigma: float) -> np.ndarray:
-    """Compute the gaussian (RBF) kernel matrix K, with K_ij = exp(-gamma |x_i - y_j|^2)
-    and gamma = 1/(2*sigma).
+    """Compute the gaussian (RBF) kernel matrix.
+
+    The computed kernel matrix K has elements :math:`K_ij = exp(-gamma |x_i - y_j|^2)`
+    where :math:`gamma = 1/(2*sigma)`.
 
     Args:
         x_i: Samples A (integers).
@@ -61,7 +63,7 @@ def compute_multi_rbf_kernel(
 ) -> np.ndarray:
     """Compute the multi-gaussian (RBF) kernel matrix K, with
 
-    K_ij = 1/N * Sum_n [exp(-gamma_n |x_i - y_j|^2)]
+    :math:`K_ij = 1/N * Sum_n [exp(-gamma_n |x_i - y_j|^2)]`
 
     with n = 1,...,N and gamma = 1/(2*sigma).
 
@@ -97,10 +99,10 @@ def compute_mmd(
         Args:
             target_distribution: The target probability distribution.
             measured_distribution: The measured probability distribution.
+            distance_measure_parameters: dictionary with the following keys:
 
-            distance_measure_parameters:
-                sigma (float/np.array): the bandwidth parameter used to compute the
-                    single/multi gaussian kernel. The default value is 1.0.
+                - sigma (float/np.array): the bandwidth parameter used to compute the
+                  single/multi gaussian kernel. The default value is 1.0.
 
         Returns:
             The value of the maximum mean discrepancy.
