@@ -17,6 +17,7 @@ import re
 import warnings
 from collections import OrderedDict
 from itertools import chain, product
+from numbers import Number
 from typing import (
     Any,
     Dict,
@@ -165,7 +166,7 @@ class PauliTerm:
         self._ops: Dict[int, str] = {
             idx: op for idx, op in operator.items() if op != "I"
         }
-        self.coefficient = complex(1.0 if coefficient is None else coefficient)
+        self.coefficient = 1.0 if coefficient is None else coefficient
 
     @staticmethod
     def from_iterable(
@@ -204,7 +205,7 @@ class PauliTerm:
     def identity() -> "PauliTerm":
         return PauliTerm("I0", 1.0)
 
-    def copy(self, new_coefficient: complex = None) -> "PauliTerm":
+    def copy(self, new_coefficient: Optional[complex] = None) -> "PauliTerm":
         """Copy PauliTerm, possibly changing its coefficient to a new one.
 
         The created copy is deep, in particular internal dictionary storing map
@@ -258,11 +259,16 @@ class PauliTerm:
             yield self[i], i
 
     def __hash__(self) -> int:
-        assert isinstance(self.coefficient, complex)
+        if isinstance(self.coefficient, complex):
+            coefficient_real = self.coefficient.real
+            coefficient_imag = self.coefficient.imag
+        else:
+            coefficient_real = self.coefficient
+            coefficient_imag = 0
         return hash(
             (
-                round(self.coefficient.real * HASH_PRECISION),
-                round(self.coefficient.imag * HASH_PRECISION),
+                round(coefficient_real * HASH_PRECISION),
+                round(coefficient_imag * HASH_PRECISION),
                 self.operations,
             )
         )
@@ -390,7 +396,7 @@ class PauliTerm:
 
 
 class PauliSum:
-    def __init__(self, terms: Union[str, Sequence[PauliTerm]] = None):
+    def __init__(self, terms: Optional[Union[str, Sequence[PauliTerm]]] = None):
         if isinstance(terms, str):
             terms = [PauliTerm(s.strip()) for s in re.split(r"\+(?![^(]*\))", terms)]
         if terms is None:
@@ -549,6 +555,10 @@ class PauliSum:
     def is_constant(self) -> bool:
         return len(self.terms) == 0 or all([term.is_constant for term in self.terms])
 
+    @property
+    def constant_term(self) -> Union[Number, complex]:
+        return sum([term.coefficient for term in self.terms if term.is_constant])
+
     @property
     def n_qubits(self) -> int:
         """Number of qubits used in this PauliSum.
